<?php
/**
 * @package     Joomla.Plugin
 * @subpackage  Content.Dxfaparse
 *
 * @copyright   Copyright (C) 2005 - 2014 dibuxo.com | Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Jtotal\Plugin\Content\Jtfaparser\Extension;

use Joomla\CMS\Factory;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\Registry\Registry;

defined('_JEXEC') or die;

/**
 * Plug-in to load FontAwsome into content (e.g. articles)
 * This uses the {fa-icon} syntax
 *
 * @package     Joomla.Plugin
 * @subpackage  Content.Dxfaparse
 * @since       1.5
 */
class JtfaParser extends CMSPlugin
{

    /**
     * Plugin that loads FontAwesome icons within content
     *
     * @param   string   $context   The context of the content being passed to the plugin.
     * @param   object   &$article  The article object.  Note $article->text is also available
     * @param   mixed    &$params   The article params
     * @param   integer  $page      The 'page' number
     *
     * @return  mixed   true if there is an error. Void otherwise.
     *
     * @since   1.6
     */
    public function onContentPrepare($context, &$article, &$params, $page = 0)
    {
        // Don't run this plugin when the content is being indexed
        if ($context == 'com_finder.indexer') {
            return true;
        }

        // Simple performance check to determine whether bot should process further
        if (strpos($article->text, 'fa-') === false) {
            return true;
        }

        // Expression to search for Dxfaparse
        $regex = '/{fa(.*?)}/i';
        //$regex        = '/{fa\s+(.*?)}/i';

        preg_match_all($regex, $article->text, $matches, PREG_SET_ORDER);

        // No matches, skip this
        if ($matches) {

            //load fontawesome font
            //jimport('joomla.application.component.helper');
            //$loadfa = JComponentHelper::getParams('com_dxfontawesome')->get('loadfa',1);
            //$load_external = JComponentHelper::getParams('com_dxfontawesome')->get('load_external',1);
            //$loadfassl = JComponentHelper::getParams('com_dxfontawesome')->get('loadfassl',0);
            //$fa_version = JComponentHelper::getParams('com_dxfontawesome')->get('faversion',4);
            //$fa5_method = JComponentHelper::getParams('com_dxfontawesome')->get('fa5_method',1);

            $plugin = PluginHelper::getPlugin('content', 'jtfaparser');
            $pluginParams = new Registry($plugin->params);

            $loadFa = $pluginParams->get('loadfa', 0);
            $loadPro = $pluginParams->get('use_pro', 0);
            $loadFrom = $pluginParams->get('loadfa_from', 'joomla');

            if ($loadFa == 1) {
                $wa = Factory::getApplication()->getDocument()->getWebAssetManager();
                if ($loadPro == 1) {
                    $wa->registerAndUseScript(
                        'fontawesome-pro',
                        $pluginParams->get('pro_kit', ''),
                        [],
                        ['crossorigin' => 'anonymous',
                        'defer' => true]
                    );
                } else {
                    if ($loadFrom == 'cdn') {
                        $wa->registerAndUseScript(
                            'fontawesome',
                            'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/js/all.min.js',
                            [],
                            ['crossorigin' => 'anonymous',
                                'referrerpolicy' => 'no-referrer',
                                'integrity' => 'sha512-fD9DI5bZwQxOi7MhYWnnNPlvXdp/2Pj3XSTRrFs5FQa4mizyGLnJcN6tuvUS6LbmgN1ut+XGSABKvjN0H6Aoow==',
                                'defer' => true]
                        );
                    } elseif ($loadFrom == 'plugin') {
                        $wa->getRegistry()->addExtensionRegistryFile('plg_content_jtfaparser');
                        $wa->useScript('jtfa_all.js');
                    } else {
                        $wa->useStyle('fontawesome', 'joomla');
                    }

                }
            }

            foreach ($matches as $match) {
                $matcheslist = explode(',', $match[0]);

                $found = trim($match[0]);

                $output = $this->_processFA($found);

                //$article->text = preg_replace("|$match[0]|", addcslashes($output, '\\$'), $article->text, 1);
                $article->text = str_replace($match[0], $output, $article->text);
            }

            /*
            if($loadfassl){
            $ssl = 'https://';
            }else{
            $ssl = 'http://';
            } */

            $document = Factory::getDocument();

            /*

            if($loadfa){

            if($fa_version == '4'){

            if($load_external){
            $document->addStyleSheet($ssl.'maxcdn.bootstrapcdn.com/font-awesome/latest/css/font-awesome.min.css');
            }else{
            $document->addStyleSheet(Uri::root().'administrator/components/com_dxfontawesome/assets/css/font-awesome.min.css');
            }

            }

            if($fa_version == '5'){

            if($fa5_method){
            $document->addCustomTag('<script defer type="text/javascript" src="https://use.fontawesome.com/releases/v5.5.0/js/all.js"></script>');
            }else{
            $document->addStyleSheet($ssl.'use.fontawesome.com/releases/v5.5.0/css/all.css');
            }

            }

            }
             */

            //end matches
        }
    }

    /**
     * AJAX handler
     *
     * @param Joomla\Event\Event $event
     *
     * @return  void
     *
     * @since  4.0.0
     */
    public function onAjaxJtfaparser($event = null)
    {

        // Get the path for the rating summary layout file
        $path = PluginHelper::getLayoutPath('content', 'jtfaparser', 'jtfaeditor');
        // Render the layout
        include $path;
        return;

        /*
    // Do not render if debugging or language debug is not enabled.
    if (!JDEBUG && !$this->debugLang) {
    return;
    }

    // User has to be authorised to see the debug information.
    if (!$this->isAuthorisedDisplayDebug() || !Session::checkToken('request')) {
    return;
    }

    switch ($this->app->input->get('action')) {
    case 'openhandler':
    $result  = $event['result'] ?: [];
    $handler = new OpenHandler($this->debugBar);

    $result[] = $handler->handle($this->app->input->request->getArray(), false, false);
    $event['result'] = $result;
    }
     */
    }

    /**
     * Loads the fa element
     *
     * @param   string  $found  The fa tag
     *
     * @return  mixed
     *
     * @since   1.6
     */
    protected function _load($found)
    {
        //var_dump($found);
        $regex_color = '/color=(.*)+\)/i';
        preg_match('/color=rgb\((.*?)\)/i', $found, $color_rgb);
        if ($color_rgb) {
            $estilo = preg_replace($regex_color, 'style="color:rgb(' . $color_rgb[1] . ')"', $found);
            $estilo = 'style="color:rgb(' . $color_rgb[1] . ')"';
        } else {
            $estilo = '';
        }

        $found = substr($found, 1, -1);
        $raso_array = explode(" ", $found);
        $raso = implode(' ', $raso_array);

        $resultado = '<i class="fa ' . $raso . '" ' . $estilo . '></i>';
        return $resultado;
    }

    /**
     * Loads the fa element
     *
     * @param   string  $found  The fa tag
     *
     * @return  mixed
     *
     * @since   1.6
     */
    protected function _processFA($found)
    {
        //var_dump($found);
        $regex_color = '/color=(.*)+\)/i';
        preg_match('/color=rgb\((.*?)\)/i', $found, $color_rgb);
        if ($color_rgb) {
            $estilo = preg_replace($regex_color, 'style="color:rgb(' . $color_rgb[1] . ')"', $found);
            $estilo = 'style="color:rgb(' . $color_rgb[1] . ')"';
        } else {
            $estilo = '';
        }

        $found = substr($found, 1, -1);
        $raso_array = explode(" ", $found);
        $raso = implode(' ', $raso_array);

        $resultado = '<i class="' . $raso . '" ' . $estilo . '></i>';
        return $resultado;
    }
}
